@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.2
+# Version   : 0.1.3
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -612,9 +612,12 @@ class AFM:
         curve(s) to remove in the input <.delete_curve(i,j,k)>
         '''
 
-        i = 0
+        curves = []
+        for curve_i in args:
+            curves = np.append(curves, curve_i)
 
-        for curve_number in args:
+        i = 0
+        for curve_number in curves:
 
             self.approach = np.delete(self.approach, curve_number, axis = 1)
             self.retract = np.delete(self.retract, curve_number, axis = 1)
@@ -632,8 +635,8 @@ class AFM:
 
             i += 1
             for j in range(i, len(args)):
-                if args[j] > curve_number:
-                    args[j] = args[j] - 1
+                if curves[j] > curve_number:
+                    curves[j] = curves[j] - 1
     
     def save_data(
         self,
